Class WorkspacePreferenceTopicCreateRequest
-
- All Implemented Interfaces:
public final class WorkspacePreferenceTopicCreateRequestRequest body for creating a preference topic.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkspacePreferenceTopicCreateRequest.BuilderA builder for WorkspacePreferenceTopicCreateRequest.
public final classWorkspacePreferenceTopicCreateRequest.DefaultStatusThe default subscription status applied when a recipient has not set their own.
public final classWorkspacePreferenceTopicCreateRequest.AllowedPreferenceA preference control a recipient may customize for a topic.
public final classWorkspacePreferenceTopicCreateRequest.TopicDataArbitrary metadata associated with the topic.
-
Method Summary
-
-
Method Detail
-
defaultStatus
final WorkspacePreferenceTopicCreateRequest.DefaultStatus defaultStatus()
The default subscription status applied when a recipient has not set their own.
-
allowedPreferences
final Optional<List<WorkspacePreferenceTopicCreateRequest.AllowedPreference>> allowedPreferences()
Preference controls a recipient may customize for this topic. Defaults to empty if omitted.
-
includeUnsubscribeHeader
final Optional<Boolean> includeUnsubscribeHeader()
Whether to include a list-unsubscribe header on emails for this topic.
-
routingOptions
final Optional<List<ChannelClassification>> routingOptions()
Default channels delivered for this topic. Defaults to empty if omitted.
-
topicData
final Optional<WorkspacePreferenceTopicCreateRequest.TopicData> topicData()
Arbitrary metadata associated with the topic.
-
_defaultStatus
final JsonField<WorkspacePreferenceTopicCreateRequest.DefaultStatus> _defaultStatus()
Returns the raw JSON value of defaultStatus.
Unlike defaultStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_allowedPreferences
final JsonField<List<WorkspacePreferenceTopicCreateRequest.AllowedPreference>> _allowedPreferences()
Returns the raw JSON value of allowedPreferences.
Unlike allowedPreferences, this method doesn't throw if the JSON field has an unexpected type.
-
_includeUnsubscribeHeader
final JsonField<Boolean> _includeUnsubscribeHeader()
Returns the raw JSON value of includeUnsubscribeHeader.
Unlike includeUnsubscribeHeader, this method doesn't throw if the JSON field has an unexpected type.
-
_routingOptions
final JsonField<List<ChannelClassification>> _routingOptions()
Returns the raw JSON value of routingOptions.
Unlike routingOptions, this method doesn't throw if the JSON field has an unexpected type.
-
_topicData
final JsonField<WorkspacePreferenceTopicCreateRequest.TopicData> _topicData()
Returns the raw JSON value of topicData.
Unlike topicData, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkspacePreferenceTopicCreateRequest.Builder toBuilder()
-
validate
final WorkspacePreferenceTopicCreateRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WorkspacePreferenceTopicCreateRequest.Builder builder()
Returns a mutable builder for constructing an instance of WorkspacePreferenceTopicCreateRequest.
The following fields are required:
.defaultStatus() .name()
-
-
-
-