Package com.courier.services.async
Class DigestServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.courier.services.async.DigestServiceAsync
public final class DigestServiceAsyncImpl implements DigestServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigestServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigestServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigestServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ScheduleServiceAsyncschedules()-
-
Method Detail
-
withRawResponse
DigestServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DigestServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
schedules
ScheduleServiceAsync schedules()
-
-
-
-