Package com.courier.services.blocking
Class DigestServiceImpl
-
- All Implemented Interfaces:
-
com.courier.services.blocking.DigestService
public final class DigestServiceImpl implements DigestService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDigestServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description DigestService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. DigestServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ScheduleServiceschedules()-
-
Method Detail
-
withRawResponse
DigestService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
DigestService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
schedules
ScheduleService schedules()
-
-
-
-